% -------------------------------------------------------------------
% ckbs: Constrained Kalman-Bucy Smoother Program: Copyright (C) 2006
% Authors: Bradlely Bell:        bradbell at washington dot edu
%          Gianluigi Pillonetto: giapi at dei dot unipd dot it
%          Aleksandr Y. Aravkin: sasha.aravkin at gmail dot com
%          James V. Burke:       burke at math dot washington dot edu
% License: GNU General Public License Version 2
% -------------------------------------------------------------------
function [ok] = affine_line_search_ok()
% There was a bug in the ckbs_affine line search that was demonstrated by 
% this test (Sasha: 2010-03-25)
N       = 30;     % number of time points
max_itr = 50;     % maximum number of interior point iterations 
epsilon = 1e-5;   % convergence criteria for the interior point iterations
ell     = 2;      % number of constraints per time point
m       = 1;      % number of measurements per time point
n       = 3;      % number of state components per time point
z       = [ ...
0.87752  1.49060  1.69015  2.05046  2.29381  2.50358  2.58554  2.82418  ...
3.01839  3.15569  3.28171  3.52932  3.59516  3.73028  3.92027  3.85684  ...
4.18965  4.23531  4.43462  4.39548  4.56385  4.61281  4.84904  4.90752  ...
4.97688  5.18607  5.29183  5.18885  5.47631  5.28934  ...
];
b       = -29.75 * ones(ell, N);
g       =  1     * ones(n, N);
h       = .35355 * ones(m, N);
db      = zeros(ell, n, N);
for k = 1 : N
	db(:,:,k) = [ 1 0 0 ; 0 1 0 ];
end  
dg      = zeros(n, n, N);
for k = 2 : N
	dg(:,:,k) = eye(n);
end
dh      = zeros(m, n, N);
for k = 1 : N
	dh(1, 1, k) = .70711;
end
qinv    = zeros(n, n, N);
for k = 1 : N
	qinv(:,:,k) = eye(n);
end
rinv    = ones(m,m,N);
%
[xOut, uOut, info] = ckbs_affine(...
	max_itr, ...
	epsilon, ...
     z, ...
	b, ...
	g, ...
	h, ...
	db, ...
	dg, ...
	dh, ...
	qinv, ...
	rinv ...
);
ok   = true;
ok   = ok & all( info(end, 1:3) <= epsilon);
d    = ckbs_sumsq_grad(xOut, z, g, h, dg, dh, qinv, rinv);
for k = 1 : N
	xk = xOut(:, k);
	uk = uOut(:, k);
	bk = b(:, k);
	Bk = db(:,:, k);
	dk = d(:, k);
	sk = - bk - Bk * xk;
	%
	ok = ok & (min(uk) >= 0.);
	ok = ok & (max (bk + Bk * xk) <= epsilon);
	ok = ok & (max ( abs( Bk' * uk + dk ) ) <= epsilon);
	ok = ok & (max ( uk .* sk ) <= epsilon );
end
